Welcome to scikit-network's documentation!
==========================================

.. include:: readme.rst

.. toctree::
   :maxdepth: 1
   :caption: Getting started

   first_steps

.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   tutorials/data/index
   tutorials/topology/index
   tutorials/path/index
   tutorials/clustering/index
   tutorials/hierarchy/index
   tutorials/ranking/index
   tutorials/classification/index
   tutorials/embedding/index
   tutorials/linkpred/index
   tutorials/visualization/index

.. toctree::
   :maxdepth: 2
   :caption: Reference

   reference/data
   reference/topology
   reference/path
   reference/clustering
   reference/hierarchy
   reference/ranking
   reference/classification
   reference/embedding
   reference/linkpred
   reference/linalg
   reference/utils
   reference/visualization

.. toctree::
   :maxdepth: 1
   :caption: About

   authors
   history
   contributing
   genindex
   glossary
